import { Ref } from 'vue'
import _ from 'lodash'
import { CommonData, CommonTableColumn } from '~/common'

export function useTableFilterAndSort(
  tableColumns: Ref<CommonTableColumn[]>,
  tableData: Ref<CommonData[]>
) {
  watch([tableColumns, tableData], ([columns, records]) => {
    const tempSets = {}
    columns.forEach(column => {
      if (column.needFilters) {
        tempSets[column.columnName] = new Set()
      }
    })
    records.forEach(item => {
      Object.keys(tempSets).forEach(key => {
        '' !== (item[key] ?? '') && tempSets[key].add(String(item[key]))
      })
    })
    Object.keys(tempSets).forEach(key => {
      filterOptionMap[key] = _.orderBy(
        [...tempSets[key]].map(value => ({
          text: value,
          value,
        })),
        o => o.value
      )
    })
  })

  const filterOptionMap = reactive({})
  const filterValueMap = reactive<{ [x: string]: string[] }>({})
  const tableDataSortRuleMap = reactive<{ [x: string]: string }>({})
  const dealedTableData = computed(() => {
    const filtered = tableData.value.filter(item => {
      let flag = true
      Object.entries(filterValueMap).forEach(([key, arr]) => {
        if (arr.length && !arr.includes(String(item[key]))) {
          flag = false
        }
      })
      return flag
    })
    const sortRules = Object.entries(tableDataSortRuleMap).reduce(
      (pre: [string[], ('asc' | 'desc')[]], [key, value]) => {
        if (value) {
          pre[0].push(key)
          pre[1].push(value === 'ascending' ? 'asc' : 'desc')
        }
        return pre
      },
      [[], []]
    )
    return _.orderBy(filtered, sortRules[0], sortRules[1])
  })

  return {
    filterOptionMap,
    filterValueMap,
    tableDataSortRuleMap,
    dealedTableData,
  }
}
