import { Query } from '@/api/webApi'
import { CommonValue, CommonData, CommonTableColumn } from '~/common'

const idGetter = (name: string) => {
  if (name.endsWith('WaybillGoods')) {
    return DATACONTENT_ID.waybillGoods
  } else {
    return DATACONTENT_ID[name.slice(0, 1).toLowerCase() + name.slice(1)]
  }
}

const tableColumnsMap: {
  [tableName: string]: ({
    columnLabel: string
    columnName: string
  } & { [x: string]: any })[]
} = {
  DepartureFlightContainer: [
    { columnLabel: '集装器编号', columnName: 'stowageNo', width: 120 },
    { columnLabel: '运单数', columnName: 'list', width: 60, needCount: 1 },
    { columnLabel: '件数', columnName: 'number', width: 60, needCount: 1 },
    {
      columnLabel: '理货',
      columnName: 'tally',
      className: 'cell-filter cell-filter-yellow',
    },
    {
      columnLabel: '拉下',
      columnName: 'pull',
      className: 'cell-filter cell-filter-yellow',
    },
    {
      columnLabel: '待运区',
      columnName: 'wait',
      className: 'cell-filter cell-filter-yellow',
    },
    {
      columnLabel: '货站交接',
      columnName: 'depot',
      className: 'cell-filter cell-filter-yellow',
    },
    {
      columnLabel: '机下交接',
      columnName: 'planeDown',
      className: 'cell-filter cell-filter-yellow',
    },
    {
      columnLabel: '装机',
      columnName: 'loadPlane',
      className: 'cell-filter cell-filter-yellow',
    },
  ],
  DepartureFlightWaybill: [
    { columnLabel: '运单号', columnName: 'stockCode', width: 120 },
    { columnLabel: '集装器数量', columnName: 'stowageNum', needCount: 1 },
    {
      columnLabel: '品名',
      columnName: 'typeCode',
      width: 160,
      showOverflowTooltip: true,
    },
    { columnLabel: '特货信息', columnName: 'speCargoInfo' },
    { columnLabel: '货物件数', columnName: 'luggageCount', needCount: 1 },
    { columnLabel: '拉下件数', columnName: 'pullNum', needCount: 1 },
    { columnLabel: '退运件数', columnName: 'returnNum', needCount: 1 },
    { columnLabel: '最新节点', columnName: 'nodeCode' },
    { columnLabel: '最新位置', columnName: 'execPosition' },
    { columnLabel: '处理结果', columnName: 'execResult' },
    { columnLabel: '处理时间', columnName: 'execTime', width: 130 },
    { columnLabel: '中转进航班号', columnName: 'inFlightNO' },
    {
      columnLabel: '中转航班降落时间',
      columnName: 'inFlightNOLandTime',
      width: 130,
    },
    { columnLabel: '装载序号', columnName: 'queueNo' },
  ],
  DepartureWaybillGoods: [
    {
      columnLabel: '航班号',
      columnName: 'flightNO',
      needFilters: 1,
      width: 70,
    },
    {
      columnLabel: '集装器编号',
      columnName: 'stowageNo',
      width: 100,
      needFilters: 1,
    },
    { columnLabel: '货物编码', columnName: 'CargoNo', needFilters: 1 },
    { columnLabel: '拉下', columnName: 'pullMark', needFilters: 1, width: 60 },
    {
      columnLabel: '退运',
      columnName: 'returnMark',
      needFilters: 1,
      width: 60,
    },
    {
      columnLabel: '收货核单',
      columnName: 'DEH',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '查验',
      columnName: 'ACC_CHECK',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '拒运',
      columnName: 'ACC_CHECK_2',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '安检',
      columnName: '安检',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '加货',
      columnName: 'ACC_BUP',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '待运区',
      columnName: 'WAT_LOC',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '货站交接',
      columnName: 'CARGOS_DEP_ULD_HANDOVER',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '机下交接',
      columnName: '出港货邮',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '装机',
      columnName: '装载完成',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '拉下',
      columnName: 'CARGOS_OFFLOAD',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '拉回',
      columnName: 'OFFLOAD_CONFIRM',
      className: 'cell-filter cell-filter-green',
    },
    // {
    //   columnLabel: '起飞',
    //   columnName: 'C15',
    //   className: 'cell-filter cell-filter-green',
    // },
    {
      columnLabel: '退运',
      columnName: 'BILL_RETURN',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '卸机',
      columnName: 'CARGOS_ARR_HANDOVER',
      className: 'cell-filter cell-filter-cyan',
    },
    {
      columnLabel: '机下交接',
      columnName: 'CARGOS_HANDOVER_STATUS',
      className: 'cell-filter cell-filter-cyan',
    },
    {
      columnLabel: '货站交接',
      columnName: '货站交接',
      className: 'cell-filter cell-filter-cyan',
    },
    {
      columnLabel: '理货',
      columnName: 'IMP_TALLY',
      className: 'cell-filter cell-filter-cyan',
    },
    {
      columnLabel: '出库',
      columnName: 'FSU_DLV',
      className: 'cell-filter cell-filter-cyan',
    },
  ],
  DepartureGoodsFlight: [
    { columnLabel: '航班号', columnName: 'C0' },
    { columnLabel: '航班日期', columnName: 'C1' },
    { columnLabel: '起飞航站\n预计起飞时间', columnName: 'C2' },
    { columnLabel: '目的航站\n预计降落时间', columnName: 'C3' },
    { columnLabel: '节点名称', columnName: 'C4' },
    { columnLabel: '位置码', columnName: 'C5' },
    { columnLabel: '位置描述', columnName: 'C6' },
    { columnLabel: '处理时间', columnName: 'C7' },
    { columnLabel: '处理结果', columnName: 'C8' },
    { columnLabel: '数据来源', columnName: 'C9' },
    { columnLabel: '设备ID', columnName: 'C10' },
    { columnLabel: '操作人', columnName: 'C11' },
    { columnLabel: '发往位置', columnName: 'C12' },
    { columnLabel: '发往位置描述', columnName: 'C13' },
    { columnLabel: '集装器编号', columnName: 'C14' },
  ],
  ArrivalFlightWaybill: [
    { columnLabel: '运单号', columnName: 'stockCode', width: 120 },
    {
      columnLabel: '品名',
      columnName: 'typeCode',
      width: 160,
      showOverflowTooltip: true,
    },
    { columnLabel: '特货信息', columnName: 'speCargoInfo', needCount: 1 },
    {
      columnLabel: '进港报文货物件数',
      columnName: 'messageCargos_in',
      needCount: 1,
    },
    {
      columnLabel: '进港实际货物件数',
      columnName: 'acCargos_in',
      needCount: 1,
    },
    { columnLabel: '最新节点', columnName: 'nodeCode' },
    { columnLabel: '最新位置', columnName: 'execPosition' },
    { columnLabel: '处理结果', columnName: 'execResult' },
    { columnLabel: '处理时间', columnName: 'execTime', width: 130 },
    { columnLabel: '中转出航班号', columnName: 'transferFlightNO' },
    {
      columnLabel: '中转航班起飞时间',
      columnName: 'transferFlightDepTime',
      width: 130,
    },
    { columnLabel: '装载序号', columnName: 'queueNo' },
  ],
  ArrivalWaybillGoods: [
    {
      columnLabel: '航班号',
      columnName: 'flightNO',
      needFilters: 1,
      width: 70,
    },
    {
      columnLabel: '货物编码',
      columnName: 'CargoNo',
      width: 100,
      needFilters: 1,
    },
    { columnLabel: '中转', columnName: 'transMark', needFilters: 1 },
    { columnLabel: '拉下', columnName: 'pullMark', needFilters: 1, width: 60 },
    {
      columnLabel: '退运',
      columnName: 'returnMark',
      needFilters: 1,
      width: 60,
    },
    {
      columnLabel: '卸机',
      columnName: 'CARGOS_ARR_HANDOVER',
      className: 'cell-filter cell-filter-cyan',
    },
    {
      columnLabel: '机下交接',
      columnName: 'CARGOS_HANDOVER_STATUS',
      className: 'cell-filter cell-filter-cyan',
    },
    {
      columnLabel: '货站交接',
      columnName: '货站交接',
      className: 'cell-filter cell-filter-cyan',
    },
    {
      columnLabel: '理货',
      columnName: 'IMP_TALLY',
      className: 'cell-filter cell-filter-cyan',
    },
    {
      columnLabel: '出库',
      columnName: 'FSU_DLV',
      className: 'cell-filter cell-filter-cyan',
    },
    {
      columnLabel: '收货核单',
      columnName: 'DEH',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '查验',
      columnName: 'ACC_CHECK',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '拒运',
      columnName: 'ACC_CHECK_2',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '安检',
      columnName: '安检',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '加货',
      columnName: 'ACC_BUP',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '待运区',
      columnName: 'WAT_LOC',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '货站交接',
      columnName: 'CARGOS_DEP_ULD_HANDOVER',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '机下交接',
      columnName: '出港货邮',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '装机',
      columnName: '装载完成',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '拉下',
      columnName: 'CARGOS_OFFLOAD',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '拉回',
      columnName: 'OFFLOAD_CONFIRM',
      className: 'cell-filter cell-filter-green',
    },
    // {
    //   columnLabel: '起飞',
    //   columnName: 'C15',
    //   className: 'cell-filter cell-filter-green',
    // },
    {
      columnLabel: '退运',
      columnName: 'BILL_RETURN',
      className: 'cell-filter cell-filter-green',
    },
  ],
  ArrivalGoodsFlight: [
    { columnLabel: '航班号', columnName: 'C0' },
    { columnLabel: '航班日期', columnName: 'C1' },
    { columnLabel: '起飞航站\n预计起飞时间', columnName: 'C2' },
    { columnLabel: '目的航站\n预计降落时间', columnName: 'C3' },
    { columnLabel: '节点名称', columnName: 'C4' },
    { columnLabel: '位置码', columnName: 'C5' },
    { columnLabel: '位置描述', columnName: 'C6' },
    { columnLabel: '处理时间', columnName: 'C7' },
    { columnLabel: '处理结果', columnName: 'C8' },
    { columnLabel: '数据来源', columnName: 'C9' },
    { columnLabel: '设备ID', columnName: 'C10' },
    { columnLabel: '操作人', columnName: 'C11' },
    { columnLabel: '发往位置', columnName: 'C12' },
    { columnLabel: '发往位置描述', columnName: 'C13' },
  ],
  InternationalDepartureFlightContainer: [
    { columnLabel: '集装器编号', columnName: 'C0', width: 120 },
    { columnLabel: '运单数', columnName: 'C1', width: 60, needCount: 1 },
    { columnLabel: '件数', columnName: 'C2', width: 60, needCount: 1 },
    {
      columnLabel: '理货',
      columnName: 'C3',
      className: 'cell-filter cell-filter-yellow',
    },
    {
      columnLabel: '拉下',
      columnName: 'C4',
      className: 'cell-filter cell-filter-yellow',
    },
    {
      columnLabel: '待运区',
      columnName: 'C5',
      className: 'cell-filter cell-filter-yellow',
    },
    {
      columnLabel: '货站交接',
      columnName: 'C6',
      className: 'cell-filter cell-filter-yellow',
    },
    {
      columnLabel: '机下交接',
      columnName: 'C7',
      className: 'cell-filter cell-filter-yellow',
    },
    {
      columnLabel: '装机',
      columnName: 'C8',
      className: 'cell-filter cell-filter-yellow',
    },
  ],
  InternationalDepartureFlightWaybill: [
    { columnLabel: '运单号', columnName: 'C0', width: 120 },
    { columnLabel: '运单类型', columnName: 'C1', needCount: 1 },
    { columnLabel: '集装器数量', columnName: 'C2', needCount: 1 },
    {
      columnLabel: '品名',
      columnName: 'C3',
      width: 160,
      showOverflowTooltip: true,
    },
    { columnLabel: '特货信息', columnName: 'C4' },
    { columnLabel: '货物件数', columnName: 'C5', needCount: 1 },
    { columnLabel: '拉下件数', columnName: 'C6', needCount: 1 },
    { columnLabel: '退运件数', columnName: 'C7', needCount: 1 },
    { columnLabel: '最新节点', columnName: 'C8' },
    { columnLabel: '最新位置', columnName: 'C9' },
    { columnLabel: '处理结果', columnName: 'C10' },
    { columnLabel: '处理时间', columnName: 'C11', width: 130 },
    { columnLabel: '中转进航班号', columnName: 'C12' },
    { columnLabel: '中转航班降落时间', columnName: 'C13', width: 130 },
    { columnLabel: '装载序号', columnName: 'C14' },
  ],
  InternationalDepartureWaybillGoods: [
    { columnLabel: '航班号', columnName: 'C0', needFilters: 1 },
    { columnLabel: '集装器编号', columnName: 'C1', width: 120, needFilters: 1 },
    { columnLabel: '货物编码', columnName: 'C2', needFilters: 1 },
    { columnLabel: '拉下', columnName: 'C3', needFilters: 1 },
    { columnLabel: '退运', columnName: 'C4', needFilters: 1 },
    {
      columnLabel: '入园',
      columnName: 'C5',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '海关',
      columnName: 'C6',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '运抵',
      columnName: 'C7',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '安检',
      columnName: 'C8',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '收运核单',
      columnName: 'C9',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '理货',
      columnName: 'C10',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '拉下',
      columnName: 'C11',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '待运区',
      columnName: 'C12',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '货站交接',
      columnName: 'C13',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '机下交接',
      columnName: 'C14',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '提取',
      columnName: 'C15',
      className: 'cell-filter cell-filter-green',
    },
  ],
  InternationalDepartureGoodsFlight: [
    { columnLabel: '航班号', columnName: 'C0' },
    { columnLabel: '航班日期', columnName: 'C1' },
    { columnLabel: '起飞航站\n预计起飞时间', columnName: 'C2' },
    { columnLabel: '目的航站\n预计降落时间', columnName: 'C3' },
    { columnLabel: '节点名称', columnName: 'C4' },
    { columnLabel: '位置码', columnName: 'C5' },
    { columnLabel: '位置描述', columnName: 'C6' },
    { columnLabel: '处理时间', columnName: 'C7' },
    { columnLabel: '处理结果', columnName: 'C8' },
    { columnLabel: '数据来源', columnName: 'C9' },
    { columnLabel: '设备ID', columnName: 'C10' },
    { columnLabel: '操作人', columnName: 'C11' },
    { columnLabel: '发往位置', columnName: 'C12' },
    { columnLabel: '发往位置描述', columnName: 'C13' },
    { columnLabel: '集装器编号', columnName: 'C14' },
  ],
  InternationalArrivalFlightWaybill: [
    { columnLabel: '运单号', columnName: 'stockCode', width: 120 },
    {
      columnLabel: '品名',
      columnName: 'typeCode',
      width: 160,
      showOverflowTooltip: true,
    },
    { columnLabel: '特货信息', columnName: 'speCargoInfo', needCount: 1 },
    {
      columnLabel: '进港报文货物件数',
      columnName: 'messageCargos_in',
      needCount: 1,
    },
    {
      columnLabel: '进港实际货物件数',
      columnName: 'acCargos_in',
      needCount: 1,
    },
    { columnLabel: '最新节点', columnName: 'nodeCode' },
    { columnLabel: '最新位置', columnName: 'execPosition' },
    { columnLabel: '处理结果', columnName: 'execResult' },
    { columnLabel: '处理时间', columnName: 'execTime', width: 130 },
    { columnLabel: '中转出航班号', columnName: 'transferFlightNO' },
    {
      columnLabel: '中转航班起飞时间',
      columnName: 'transferFlightDepTime',
      width: 130,
    },
    { columnLabel: '装载序号', columnName: 'queueNo' },
  ],
  InternationalArrivalWaybillGoods: [
    { columnLabel: '航班号', columnName: 'C0', needFilters: 1 },
    { columnLabel: '货物编码', columnName: 'C1', needFilters: 1 },
    { columnLabel: '中转', columnName: 'C2', needFilters: 1 },
    { columnLabel: '退运', columnName: 'C3', needFilters: 1 },
    { columnLabel: '海关异常', columnName: 'C4', needFilters: 1 },
    {
      columnLabel: '卸机',
      columnName: 'C5',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '机下交接',
      columnName: 'C6',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '货站交接',
      columnName: 'C7',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '理货',
      columnName: 'C8',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '海关放行',
      columnName: 'C9',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '出库',
      columnName: 'C10',
      className: 'cell-filter cell-filter-green',
    },
    {
      columnLabel: '海关罚没',
      columnName: 'C11',
      className: 'cell-filter cell-filter-green',
    },
  ],
  InternationalArrivalGoodsFlight: [
    { columnLabel: '航班号', columnName: 'C0' },
    { columnLabel: '航班日期', columnName: 'C1' },
    { columnLabel: '起飞航站\n预计起飞时间', columnName: 'C2' },
    { columnLabel: '目的航站\n预计降落时间', columnName: 'C3' },
    { columnLabel: '节点名称', columnName: 'C4' },
    { columnLabel: '位置码', columnName: 'C5' },
    { columnLabel: '位置描述', columnName: 'C6' },
    { columnLabel: '处理时间', columnName: 'C7' },
    { columnLabel: '处理结果', columnName: 'C8' },
    { columnLabel: '数据来源', columnName: 'C9' },
    { columnLabel: '设备ID', columnName: 'C10' },
    { columnLabel: '操作人', columnName: 'C11' },
    { columnLabel: '发往位置', columnName: 'C12' },
    { columnLabel: '发往位置描述', columnName: 'C13' },
  ],
}
const simulateTableDataMap: {
  [tableName: string]: CommonData[]
} = {
  DepartureFlightContainer: Array.from({ length: 2 }, () => ({
    C0: 'DOU29800001',
    C1: '5',
    C2: '50',
    C3: 'C24  11:01',
    C4: 'F24  12:05',
    C5: 'D32  11:25',
    C6: 'E24  11:40',
    C7: 'F24  12:01',
    C8: 'G32  12:25',
  })),
  DepartureFlightWaybill: Array.from({ length: 3 }, () => ({
    C0: '32535234445',
    C1: '5',
    C2: '手机、充电器',
    C3: '特',
    C4: '5',
    C5: '2',
    C6: '2',
    C7: '待运区',
    C8: 'A13',
    C9: '通过',
    C10: '2022/9/10 10:01',
    C11: 'ZH5466',
    C12: '2022/9/10 16:01',
    C13: '3',
  })),
  DepartureWaybillGoods: Array.from({ length: 4 }, () => ({
    C0: 'CA1001',
    C1: 'DOU2424U2',
    C2: '56888829',
    C3: 'Y',
    C4: 'Y',
    C5: 'A203-未通过-15:40',
    C6: 'A203-未通过-15:40',
    C7: 'A203-未通过-15:40',
    C8: 'A203-未通过-15:40',
    C9: 'A203-未通过-15:40',
    C10: 'A203-未通过-15:40',
    C11: 'A203-未通过-15:40',
    C12: 'A203-未通过-15:40',
    C13: 'A203-未通过-15:40',
    C14: 'A203-未通过-15:40',
    C15: 'A203-未通过-15:40',
    C16: 'A203-未通过-15:40',
  })),
  DepartureGoodsFlight: Array.from({ length: 3 }, () => ({
    C0: 'CA1001',
    C1: '2022/9/10',
    C2: 'SZX-11:35',
    C3: 'PEK-14:35',
    C4: '机下交接',
    C5: 'A03',
    C6: 'A区03闸口',
    C7: '2022/09/10 07:10',
    C8: '通过',
    C9: '人工扫描',
    C10: '56',
    C11: '张伯伦',
    C12: 'B12',
    C13: '货站B12闸口',
    C14: 'DOU2329U2',
  })),
  ArrivalFlightWaybill: Array.from({ length: 3 }, () => ({
    C0: '32535234445',
    C1: '手机、充电器',
    C2: '特',
    C3: '5',
    C4: '5',
    C5: '待运区',
    C6: 'A13',
    C7: '通过',
    C8: '2022/9/10 10:01',
    C9: 'ZH5466',
    C10: '2022/9/10 16:01',
    C11: '3',
  })),
  ArrivalWaybillGoods: Array.from({ length: 4 }, () => ({
    C0: 'CA1001',
    C1: '56888829',
    C2: 'Y',
    C3: 'Y',
    C4: 'Y',
    C5: 'A203-未通过-15:40',
    C6: 'A203-未通过-15:40',
    C7: 'A203-未通过-15:40',
    C8: 'A203-未通过-15:40',
    C9: 'A203-未通过-15:40',
    C10: 'A203-未通过-15:40',
    C11: 'A203-未通过-15:40',
    C12: 'A203-未通过-15:40',
    C13: 'A203-未通过-15:40',
    C14: 'A203-未通过-15:40',
    C15: 'A203-未通过-15:40',
    C16: 'A203-未通过-15:40',
  })),
  ArrivalGoodsFlight: Array.from({ length: 3 }, () => ({
    C0: 'CA1001',
    C1: '2022/9/10',
    C2: 'SZX-11:35',
    C3: 'PEK-14:35',
    C4: '机下交接',
    C5: 'A03',
    C6: 'A区03闸口',
    C7: '2022/09/10 07:10',
    C8: '通过',
    C9: '人工扫描',
    C10: '56',
    C11: '张伯伦',
    C12: 'B12',
    C13: '货站B12闸口',
    C14: 'DOU2329U2',
  })),
  InternationalDepartureFlightContainer: Array.from({ length: 2 }, () => ({
    C0: 'DOU29800001',
    C1: '5',
    C2: '50',
    C3: 'C24  11:01',
    C4: 'F24  12:05',
    C5: 'D32  11:25',
    C6: 'E24  11:40',
    C7: 'F24  12:01',
    C8: 'G32  12:25',
  })),
  InternationalDepartureFlightWaybill: Array.from({ length: 3 }, () => ({
    C0: '32535234445',
    C1: '国际普货',
    C2: '5',
    C3: '手机、充电器',
    C4: '特',
    C5: '5',
    C6: '2',
    C7: '2',
    C8: '待运区',
    C9: 'A13',
    C10: '通过',
    C11: '2022/9/10 10:01',
    C12: 'ZH5466',
    C13: '2022/9/10 16:01',
    C14: '3',
  })),
  InternationalDepartureWaybillGoods: Array.from({ length: 4 }, () => ({
    C0: 'CA1001',
    C1: 'DOU2424U2',
    C2: '56888829',
    C3: 'Y',
    C4: 'Y',
    C5: 'A203-未通过-15:40',
    C6: 'A203-未通过-15:40',
    C7: 'A203-未通过-15:40',
    C8: 'A203-未通过-15:40',
    C9: 'A203-未通过-15:40',
    C10: 'A203-未通过-15:40',
    C11: 'A203-未通过-15:40',
    C12: 'A203-未通过-15:40',
    C13: 'A203-未通过-15:40',
    C14: 'A203-未通过-15:40',
    C15: 'A203-未通过-15:40',
  })),
  InternationalDepartureGoodsFlight: Array.from({ length: 3 }, () => ({
    C0: 'CA1001',
    C1: '2022/9/10',
    C2: 'SZX-11:35',
    C3: 'PEK-14:35',
    C4: '机下交接',
    C5: 'A03',
    C6: 'A区03闸口',
    C7: '2022/09/10 07:10',
    C8: '通过',
    C9: '人工扫描',
    C10: '56',
    C11: '张伯伦',
    C12: 'B12',
    C13: '货站B12闸口',
    C14: 'DOU2329U2',
  })),
  InternationalArrivalFlightWaybill: Array.from({ length: 3 }, () => ({
    C0: '32535234445',
    C1: '国际普货',
    C2: '手机、充电器',
    C3: '特',
    C4: '5',
    C5: '2',
    C6: '理货',
    C7: 'A13',
    C8: '通过',
    C9: '2022/9/10 10:01',
    C10: 'ZH5466',
    C11: '2022/9/10 16:01',
    C12: '3',
  })),
  InternationalArrivalWaybillGoods: Array.from({ length: 4 }, () => ({
    C0: 'CA1001',
    C1: '56888829',
    C2: 'Y',
    C3: 'Y',
    C4: 'Y',
    C5: 'A203-未通过-15:40',
    C6: 'A203-未通过-15:40',
    C7: 'A203-未通过-15:40',
    C8: 'A203-未通过-15:40',
    C9: 'A203-未通过-15:40',
    C10: 'A203-未通过-15:40',
    C11: 'A203-未通过-15:40',
  })),
  InternationalArrivalGoodsFlight: Array.from({ length: 3 }, () => ({
    C0: 'CA1001',
    C1: '2022/9/10',
    C2: 'SZX-11:35',
    C3: 'PEK-14:35',
    C4: '机下交接',
    C5: 'A03',
    C6: 'A区03闸口',
    C7: '2022/09/10 07:10',
    C8: '通过',
    C9: '人工扫描',
    C10: '56',
    C11: '张伯伦',
    C12: 'B12',
    C13: '货站B12闸口',
  })),
}

export function useTable(tableName: string, dataContent?: CommonValue[]) {
  const tableColumns = ref<CommonTableColumn[]>([])
  const tableData = ref<CommonData[]>([])
  const getTableColumns = () => {
    tableColumns.value = tableColumnsMap[tableName].map(column => ({
      columnDescribe: '',
      dataType: '',
      listqueryTemplateID: null,
      needCount: null,
      needFilters: null,
      needGroup: null,
      needSearch: null,
      needShow: 1,
      needSort: null,
      orderNumber: null,
      queryTemplateColumnSetID: null,
      queryTemplateID: null,
      ...column,
    }))
  }
  const getTableData = async () => {
    try {
      const {
        code,
        returnData: { listValues },
        message,
      } = await Query<CommonData>({
        id: idGetter(tableName),
        dataContent,
      })
      if (Number(code) !== 0) {
        throw new Error(message || '失败')
      }
      tableData.value = listValues.filter(
        row =>
          !Object.values(row).some(
            cellValue =>
              typeof cellValue === 'string' && cellValue.includes('undefined')
          )
      )
    } catch (error) {
      console.error(error)
    }
  }
  const getSimulateTableData = () => {
    tableData.value = simulateTableDataMap[tableName]
  }

  onMounted(() => {
    if (tableColumnsMap[tableName]) {
      getTableColumns()
      getTableData()
      // getSimulateTableData()
    }
  })

  return {
    tableColumns,
    tableData,
  }
}
